Eigen-box
=========

Calculates the eigenvalues and eigenvectors of a simple wave in a 1D box.

Build and run like:

    make && ./eigen-box

and visualise the eigenvalues and eigenvectors with:

    ./eigenvals.py

Click individual eigenvalues in the top plot to see the corresponding
eigenvector in the bottom plot.
